@@ -2,20 +2,19 @@ package Catalyst::View::GD::Barcode::QRcode;
 
 use strict;
 use warnings;
-
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use base qw(Catalyst::View);
-use NEXT;
-use Catalyst::Exception;
 
+use MRO::Compat;
 use GD::Barcode::QRcode;
 
 __PACKAGE__->mk_accessors(qw( ecc version module_size img_type ));
 
 sub new {
-    my ($class, $c, $args) = @_;
-    my $self = $class->NEXT::new($c);
+    my ($self) = shift;
+    my ($c, $args) = @_;
+    my $self = $self->next::method(@_);
 
     for my $field (keys %$args) {
         if ($self->can($field)) {
@@ -24,6 +23,7 @@ sub new {
             $c->log->debug("Unknown config parameter $field") if $c->debug;
         }
     }
+    return $self
 }
 
 sub process {
@@ -109,37 +109,6 @@ Or change configuration dynamically
         $c->forward( $c->view( 'QRcode' ) );
     }
 
-If you use 'Catalyst::Plugin::DefaultEnd', in your application class
-
-    sub qrcode : Local {
-        my ( $self, $c) = @_;
-
-        $c->stash->{qrcode} = 'http://www.cpan.org';
-    }
-
-    sub end : Private {
-        my ( $self, $c ) = @_;
-        $c->forward( $c->view( 'QRCode' ) ) if $c->stash->{qrcode};
-        $self->NEXT::end( $c );
-    }
-
-Or with 'Catalyst::Action::RenderView'
-
-    sub render : ActionClass('RenderView') {}
-
-    sub end : Private {
-        my ( $self, $c ) = @_;
-        
-        $c->detach( $c->view( 'QRCode' ) ) if $c->stash->{qrcode};
-        $c->forward('render');
-    }
-
-Then you can get QRcode image from http://localhost:3000/qrcode
-
-For Template::Toolkit
-
-    <img src="[%c.uri_for('/qrcode') %]"/>
-
 =head1 DESCRIPTION
 
 Catalyst::View::GD::Barcode::QRcode is the Catalyst view class for GD::Barcode::QRcode, create QRcode barcode image with GD.
@@ -181,10 +150,3 @@ The full text of the license can be found in the
 LICENSE file included with this module.
 
 
-
-=head1 SEE ALSO
-
-F<Catalyst>, F<GD::Barcode::QRcode>.
-
-
-=cut
